* Encoding: UTF-8.

* Simulation zur WLS-Regression.

SET SEED = 4720.

COMPUTE xs = uniform(1).
COMPUTE ys = xs + normal(xs).

COMPUTE y_w = ys/xs.
COMPUTE c_w = 1/xs.

* OLS-Regression unter Vernachlssigung der Varianzheterogenitt.
REGRESSION
  /MISSING LISTWISE
  /STATISTICS COEFF OUTS CI(95) R ANOVA
  /CRITERIA=PIN(.05) POUT(.10)
  /NOORIGIN
  /DEPENDENT ys
  /METHOD=ENTER xs
  /SCATTERPLOT=(*SDRESID ,*ZPRED )
 /SAVE=RESID .

* Breusch-Pagen - Heteroskedastizittstest und HC3-Standardfehler fr die Ausgangsvariablen.
UNIANOVA ys WITH xs
  /METHOD=SSTYPE(3)
  /INTERCEPT=INCLUDE
  /PRINT MBP
  /CRITERIA=ALPHA(.05)  
  /ROBUST=HC3
  /DESIGN=xs.

* WLS-Regression.
WLS ys  WITH xs
  /SOURCE xs
  /POWER -2 TO 3 BY 0.1
  /CONSTANT
  /SAVE WEIGHT
  /PRINT BEST.

* Zur Probe gerechnete OLS-Regression mit Kriterium y_w und Regressor c_w.
REGRESSION
  /MISSING LISTWISE
  /STATISTICS COEFF OUTS CI(95) R ANOVA
  /CRITERIA=PIN(.05) POUT(.10)
  /NOORIGIN
  /DEPENDENT y_w
  /METHOD=ENTER c_w 
  /SCATTERPLOT=(*SDRESID ,*ZPRED ) 
  /SAVE =RESID.

* Breusch-Pagen - Heteroskedastizittstest fr die transformierten Variablen.
UNIANOVA y_w WITH c_w
  /METHOD=SSTYPE(3)
  /INTERCEPT=INCLUDE
  /PRINT MBP
  /CRITERIA=ALPHA(.05)
  /DESIGN=c_w.

* Die von SPSS berechnete Gewichtungsvariable ist gerade xs hoch -2.
COMPUTE xshm2 = xs**-2.
EXECUTE.

